@@ -28,7 +28,7 @@ use constant S_END      => 3;
 
 use constant TABSTOP    => 8;
 
-our $VERSION  = '0.04';
+our $VERSION  = '0.05';
 my @accessors = qw( save_x save_y attr state );
 
 __PACKAGE__->mk_accessors( @accessors );
@@ -416,7 +416,7 @@ simulates a tab char (8 spaces).
 
 sub tab {
 	my $self = shift;
-	my $count = $self->x % TABSTOP;
+	my $count = ( $self->x + 1 ) % TABSTOP;
 	if( $count ) {
 		$count = TABSTOP - $count;
 		for( 1..$count ) {
